==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/DAX/NotificationConfiguration.pm <==
package Paws::DAX::NotificationConfiguration;
  use Moose;
  has TopicArn => (is => 'ro', isa => 'Str');
  has TopicStatus => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DAX::NotificationConfiguration

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DAX::NotificationConfiguration object:

  $service_obj->Method(Att1 => { TopicArn => $value, ..., TopicStatus => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DAX::NotificationConfiguration object:

  $result = $service_obj->Method(...);
  $result->Att1->TopicArn

=head1 DESCRIPTION

Describes a notification topic and its status. Notification topics are
used for publishing DAX events to subscribers using Amazon Simple
Notification Service (SNS).

=head1 ATTRIBUTES


=head2 TopicArn => Str

  The Amazon Resource Name (ARN) that identifies the topic.


=head2 TopicStatus => Str

  The current state of the topic.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DAX>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/DAX/NotificationConfiguration.pm <==
package Paws::DAX::NotificationConfiguration;
  use Moose;
  has TopicArn => (is => 'ro', isa => 'Str');
  has TopicStatus => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::DAX::NotificationConfiguration

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::DAX::NotificationConfiguration object:

  $service_obj->Method(Att1 => { TopicArn => $value, ..., TopicStatus => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::DAX::NotificationConfiguration object:

  $result = $service_obj->Method(...);
  $result->Att1->TopicArn

=head1 DESCRIPTION

Describes a notification topic and its status. Notification topics are
used for publishing DAX events to subscribers using Amazon Simple
Notification Service (SNS).

=head1 ATTRIBUTES


=head2 TopicArn => Str

  The Amazon Resource Name (ARN) that identifies the topic.


=head2 TopicStatus => Str

  The current state of the topic.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::DAX>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
